Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2709)

Unified Diff: tests/language/optimized_string_charcodeat_test.dart

Issue 12282038: Remove deprecated string features. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Merge to head Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tests/language/optimized_string_charcodeat_test.dart
diff --git a/tests/language/optimized_string_charcodeat_test.dart b/tests/language/optimized_string_charcodeat_test.dart
index aa2bd640593082de25424973bc12e379788d2918..e4747f2515a2868f1059ed0556105d6411a46838 100644
--- a/tests/language/optimized_string_charcodeat_test.dart
+++ b/tests/language/optimized_string_charcodeat_test.dart
@@ -2,60 +2,60 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
// Test optimized charCodeAt and array access.
String one_byte = "hest";
String two_byte = "høns";
-int testOneByteCharCodeAt(String x, int j) {
+int testOneByteCodeUnitAt(String x, int j) {
int test() {
- return x.charCodeAt(j);
+ return x.codeUnitAt(j);
}
for (int i = 0; i < 10000; i++) test();
return test();
}
-int testTwoByteCharCodeAt(String x, int j) {
+int testTwoByteCodeUnitAt(String x, int j) {
int test() {
- return x.charCodeAt(j);
+ return x.codeUnitAt(j);
}
for (int i = 0; i < 10000; i++) test();
return test();
}
-int testConstantStringCharCodeAt(int j) {
+int testConstantStringCodeUnitAt(int j) {
int test() {
- return "høns".charCodeAt(j);
+ return "høns".codeUnitAt(j);
}
for (int i = 0; i < 10000; i++) test();
return test();
}
-int testConstantIndexCharCodeAt(String x) {
+int testConstantIndexCodeUnitAt(String x) {
int test() {
- return x.charCodeAt(1);
+ return x.codeUnitAt(1);
}
for (int i = 0; i < 10000; i++) test();
return test();
}
-int testOneByteCharCodeAtInLoop(var x) {
+int testOneByteCodeUnitAtInLoop(var x) {
var result = 0;
for (int i = 0; i < x.length; i++) {
- result += x.charCodeAt(i);
+ result += x.codeUnitAt(i);
}
return result;
}
-int testTwoByteCharCodeAtInLoop(var x) {
+int testTwoByteCodeUnitAtInLoop(var x) {
var result = 0;
for (int i = 0; i < x.length; i++) {
- result += x.charCodeAt(i);
+ result += x.codeUnitAt(i);
}
return result;
}
@@ -63,15 +63,15 @@ int testTwoByteCharCodeAtInLoop(var x) {
main() {
for (int j = 0; j < 10; j++) {
- Expect.equals(101, testOneByteCharCodeAt(one_byte, 1));
- Expect.equals(248, testTwoByteCharCodeAt(two_byte, 1));
- Expect.equals(248, testConstantStringCharCodeAt(1));
- Expect.equals(101, testConstantIndexCharCodeAt(one_byte));
+ Expect.equals(101, testOneByteCodeUnitAt(one_byte, 1));
+ Expect.equals(248, testTwoByteCodeUnitAt(two_byte, 1));
+ Expect.equals(248, testConstantStringCodeUnitAt(1));
+ Expect.equals(101, testConstantIndexCodeUnitAt(one_byte));
}
for (int j = 0; j < 2000; j++) {
- Expect.equals(436, testOneByteCharCodeAtInLoop(one_byte));
- Expect.equals(577, testTwoByteCharCodeAtInLoop(two_byte));
+ Expect.equals(436, testOneByteCodeUnitAtInLoop(one_byte));
+ Expect.equals(577, testTwoByteCodeUnitAtInLoop(two_byte));
}
- Expect.throws(() => testOneByteCharCodeAtInLoop(123));
- Expect.throws(() => testTwoByteCharCodeAtInLoop(123));
+ Expect.throws(() => testOneByteCodeUnitAtInLoop(123));
+ Expect.throws(() => testTwoByteCodeUnitAtInLoop(123));
}
« no previous file with comments | « tests/language/optimized_constant_array_string_access_test.dart ('k') | tests/language/static_inline_test.dart » ('j') | no next file with comments »
@@ -2,60 +2,60 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-// Test optimized charCodeAt and array access.
+// Test optimized CodeUnitAt and array access.
String one_byte = "hest";
String two_byte = "høns";

Powered by Google App Engine
This is Rietveld 408576698